/*
 *  uio
 *  Simple IO
 *
 *  Copyright (C) 2000 Jens Laas jens.laas@data.slu.se
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <unistd.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/time.h>
#include <sys/stat.h>
#include <sys/poll.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>

#include <stdarg.h>

#define BSIZE 1024

static char out_str[BSIZE];

/*
  Output simplifying functions:
  init_io()
  cat(char *)
  vcat(int, char *)
  cat_int(int )
  print( char * || file_descriptor)
  printn( char * || file_descriptor, int )
*/

void init_io()
{
  out_str[0] = 0;
}

void cat(char *s)
{
  int n = BSIZE - strlen(out_str)+1;
  
  strncpy(&out_str[ strlen(out_str) ], s, n);
  out_str[BSIZE-1] = 0;
}

void vcat( int n, ... )
{
  va_list ap;
  
  va_start( ap, n);
  while(n--)
    cat( va_arg(ap, char *) );
  va_end(ap);
}

void cat_int(int nr)
{
  char num[32], *n, *o;

  n = num;

  do
    {
      *n++ = '0' + nr % 10;
      nr = nr / 10;
    }
  while( nr > 0 );

  *n = 0;
  if(strlen(n)+strlen(out_str)+1 >= BSIZE)
    return;
  o = out_str + strlen(out_str);
  for(--n; n >= num; n--)
    *o++ = *n;
  *o = 0;
}


void print(char *s)
{
  if((unsigned long) s>256)
    strcpy(s, out_str);
  else
    {
      if(s == 0)
	s = (char *) 1;
      write((int)s, out_str, strlen(out_str));
    }
  out_str[0] = 0;
}

void printn(char *s, int n)
{
  if(n <= BSIZE)
    out_str[n-1] = 0;
  print(s);
}
